@@ -447,7 +447,9 @@ class PartnersClient(AbstractClient):
 
 
     def DescribeClientBaseInfo(self, request):
-        """国际站根据UIN查询代客基础信息【本接口仅限主账号访问】
+        """该接口即将下线，请切换调用DescribeClientBasicInfo。
+
+        国际站根据UIN查询代客基础信息【本接口仅限主账号访问】
 
         :param request: Request instance for DescribeClientBaseInfo.
         :type request: :class:`tencentcloud.partners.v20180321.models.DescribeClientBaseInfoRequest`
